==> jc-1.4.0.tar.gz: gnu/java/awt/peer/gtk/GtkPopupMenuPeer.h <==
// public class gnu.java.awt.peer.gtk.GtkPopupMenuPeer

// class file dependencies
// @dep_class d6f9e33c09f7be67 gnu_java_awt_peer_gtk_GtkGenericPeer
// @dep_class bf080bc730109d28 gnu_java_awt_peer_gtk_GtkMenuComponentPeer
// @dep_class a20f5263a96f04a5 gnu_java_awt_peer_gtk_GtkMenuItemPeer
// @dep_class 66ac9ea9a2d96b15 gnu_java_awt_peer_gtk_GtkMenuPeer
// @dep_class 907e3c366ce1a325 gnu_java_awt_peer_gtk_GtkPopupMenuPeer
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_java_awt_peer_gtk_GtkMenuPeer

#include "gnu/java/awt/peer/gtk/GtkMenuPeer.h"

#ifndef _JC_gnu_java_awt_peer_gtk_GtkPopupMenuPeer_H_
#define _JC_gnu_java_awt_peer_gtk_GtkPopupMenuPeer_H_

// Forward structure declarations
struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$object;
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Event$object;
struct _jc_java_awt_MenuItem$object;
struct _jc_java_awt_PopupMenu$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$sub_refs	_jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$sub_refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$sub_nonrefs	_jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$sub_nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$refs	_jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$nonrefs	_jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$object	_jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$object;

typedef const struct _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$vmethods	_jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$vmethods;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$vtable	_jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$vtable;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$vtype	_jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$vtype;

// Constructors
extern void _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$method$_init$946ef2d8c9ef9924(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$object *, struct _jc_java_awt_PopupMenu$object *);

// Virtual methods
extern void _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$method$setParent$e22b55ed7b09b3d0(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$object *, struct _jc_java_awt_MenuItem$object *);
extern void _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$method$setupAccelGroup$a19fe7bfa46a7d2d(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$object *, struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$object *);
extern void _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$method$show$93abdd4d6fada600(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$object *, jint, jint, jlong);
extern void _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$method$show$7b2df54a68d4cb4c(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$object *, struct _jc_java_awt_Component$object *, jint, jint);
extern void _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$method$show$7af905a6eebfbb6c(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$object *, struct _jc_java_awt_Event$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$method_info$setParent$e22b55ed7b09b3d0;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$method_info$setupAccelGroup$a19fe7bfa46a7d2d;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$method_info$show$93abdd4d6fada600;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$method_info$show$7b2df54a68d4cb4c;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$method_info$show$7af905a6eebfbb6c;

// Virtual methods structure
struct _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$vmethods {
	void	(*setParent$e22b55ed7b09b3d0)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$object *, struct _jc_java_awt_MenuItem$object *);
	void	(*setupAccelGroup$a19fe7bfa46a7d2d)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$object *, struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$object *);
	void	(*show$93abdd4d6fada600)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$object *, jint, jint, jlong);
	void	(*show$7b2df54a68d4cb4c)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$object *, struct _jc_java_awt_Component$object *, jint, jint);
	void	(*show$7af905a6eebfbb6c)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$object *, struct _jc_java_awt_Event$object *);
};

// Vtable
struct _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_peer_gtk_GtkGenericPeer$vmethods	gnu_java_awt_peer_gtk_GtkGenericPeer;
	_jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$vmethods	gnu_java_awt_peer_gtk_GtkMenuComponentPeer;
	_jc_gnu_java_awt_peer_gtk_GtkMenuItemPeer$vmethods	gnu_java_awt_peer_gtk_GtkMenuItemPeer;
	_jc_gnu_java_awt_peer_gtk_GtkMenuPeer$vmethods	gnu_java_awt_peer_gtk_GtkMenuPeer;
	_jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$vmethods	gnu_java_awt_peer_gtk_GtkPopupMenuPeer;
};

// Vtype
struct _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$refs {
    _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$sub_refs	gnu_java_awt_peer_gtk_GtkPopupMenuPeer;
    _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$sub_refs	gnu_java_awt_peer_gtk_GtkMenuPeer;
    _jc_gnu_java_awt_peer_gtk_GtkMenuItemPeer$sub_refs	gnu_java_awt_peer_gtk_GtkMenuItemPeer;
    _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$sub_refs	gnu_java_awt_peer_gtk_GtkMenuComponentPeer;
    _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_refs	gnu_java_awt_peer_gtk_GtkGenericPeer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkGenericPeer;
    _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkMenuComponentPeer;
    _jc_gnu_java_awt_peer_gtk_GtkMenuItemPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkMenuItemPeer;
    _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkMenuPeer;
    _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkPopupMenuPeer;
};

// Object instance structure
struct _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$object {
	_jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$vtype	*vtype;
	_jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$vtype _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_peer_gtk_GtkPopupMenuPeer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$class_object;

#endif	/* _JC_gnu_java_awt_peer_gtk_GtkPopupMenuPeer_H_ */

==> jc-1.4.5.tar.gz: gnu/java/awt/peer/gtk/GtkPopupMenuPeer.h <==
// public class gnu.java.awt.peer.gtk.GtkPopupMenuPeer

// class file dependencies
// @dep_class d6f9e33c09f7be67 gnu_java_awt_peer_gtk_GtkGenericPeer
// @dep_class bf080bc730109d28 gnu_java_awt_peer_gtk_GtkMenuComponentPeer
// @dep_class a20f5263a96f04a5 gnu_java_awt_peer_gtk_GtkMenuItemPeer
// @dep_class 66ac9ea9a2d96b15 gnu_java_awt_peer_gtk_GtkMenuPeer
// @dep_class 907e3c366ce1a325 gnu_java_awt_peer_gtk_GtkPopupMenuPeer
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_java_awt_peer_gtk_GtkMenuPeer

#include "gnu/java/awt/peer/gtk/GtkMenuPeer.h"

#ifndef _JC_gnu_java_awt_peer_gtk_GtkPopupMenuPeer_H_
#define _JC_gnu_java_awt_peer_gtk_GtkPopupMenuPeer_H_

// Forward structure declarations
struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$object;
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Event$object;
struct _jc_java_awt_MenuItem$object;
struct _jc_java_awt_PopupMenu$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$sub_refs	_jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$sub_refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$sub_nonrefs	_jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$sub_nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$refs	_jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$nonrefs	_jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$object	_jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$object;

typedef const struct _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$vmethods	_jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$vmethods;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$vtable	_jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$vtable;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$vtype	_jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$vtype;

// Constructors
extern void _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$method$_init$946ef2d8c9ef9924(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$object *, struct _jc_java_awt_PopupMenu$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$method$setParent$e22b55ed7b09b3d0(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$object *, struct _jc_java_awt_MenuItem$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$method$setupAccelGroup$a19fe7bfa46a7d2d(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$object *, struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$method$show$93abdd4d6fada600(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$object *, jint, jint, jlong) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$method$show$7b2df54a68d4cb4c(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$object *, struct _jc_java_awt_Component$object *, jint, jint) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$method$show$7af905a6eebfbb6c(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$object *, struct _jc_java_awt_Event$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$method_info$setParent$e22b55ed7b09b3d0;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$method_info$setupAccelGroup$a19fe7bfa46a7d2d;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$method_info$show$93abdd4d6fada600;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$method_info$show$7b2df54a68d4cb4c;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$method_info$show$7af905a6eebfbb6c;

// Virtual methods structure
struct _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$vmethods {
	void	(*setParent$e22b55ed7b09b3d0)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$object *, struct _jc_java_awt_MenuItem$object *) _JC_JCNI_ATTR;
	void	(*setupAccelGroup$a19fe7bfa46a7d2d)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$object *, struct _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$object *) _JC_JCNI_ATTR;
	void	(*show$93abdd4d6fada600)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$object *, jint, jint, jlong) _JC_JCNI_ATTR;
	void	(*show$7b2df54a68d4cb4c)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$object *, struct _jc_java_awt_Component$object *, jint, jint) _JC_JCNI_ATTR;
	void	(*show$7af905a6eebfbb6c)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$object *, struct _jc_java_awt_Event$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_peer_gtk_GtkGenericPeer$vmethods	gnu_java_awt_peer_gtk_GtkGenericPeer;
	_jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$vmethods	gnu_java_awt_peer_gtk_GtkMenuComponentPeer;
	_jc_gnu_java_awt_peer_gtk_GtkMenuItemPeer$vmethods	gnu_java_awt_peer_gtk_GtkMenuItemPeer;
	_jc_gnu_java_awt_peer_gtk_GtkMenuPeer$vmethods	gnu_java_awt_peer_gtk_GtkMenuPeer;
	_jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$vmethods	gnu_java_awt_peer_gtk_GtkPopupMenuPeer;
};

// Vtype
struct _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$refs {
    _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$sub_refs	gnu_java_awt_peer_gtk_GtkPopupMenuPeer;
    _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$sub_refs	gnu_java_awt_peer_gtk_GtkMenuPeer;
    _jc_gnu_java_awt_peer_gtk_GtkMenuItemPeer$sub_refs	gnu_java_awt_peer_gtk_GtkMenuItemPeer;
    _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$sub_refs	gnu_java_awt_peer_gtk_GtkMenuComponentPeer;
    _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_refs	gnu_java_awt_peer_gtk_GtkGenericPeer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkGenericPeer;
    _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkMenuComponentPeer;
    _jc_gnu_java_awt_peer_gtk_GtkMenuItemPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkMenuItemPeer;
    _jc_gnu_java_awt_peer_gtk_GtkMenuPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkMenuPeer;
    _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkPopupMenuPeer;
};

// Object instance structure
struct _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$object {
	_jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$vtype	*vtype;
	_jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$vtype _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_peer_gtk_GtkPopupMenuPeer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_peer_gtk_GtkPopupMenuPeer$class_object;

#endif	/* _JC_gnu_java_awt_peer_gtk_GtkPopupMenuPeer_H_ */
